@@ -43,8 +43,7 @@ SiBApplication::~SiBApplication() {
 }
 
 void SiBApplication::start() {
-    m_mainWindow->resize( 800, 480 );
-    m_mainWindow->showMaximized();
+    m_mainWindow->show();
     updateFileList();
 }
 
