@@ -4,13 +4,14 @@
 int main(int argc, char *argv[])
 {
     QApplication a(argc, argv);
+
+#if 1
     a.setStyleSheet( "QWidget { background: black; color: white }\
 QTableView { selection-background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #2222AA, stop: 1 #8888FF ); selection-color: white; }\
 QPushButton:disabled { color: #444444; border: 2px solid #444444; }\
-QPushButton { border: 2px solid #FFFFFF; }" );
-    a.setStyle( "motif" );
-    QApplication::setStyle( new QWindowsStyle );
-
+QPushButton { border: 2px solid #FFFFFF; }\
+QScrollBar::handle { background: white; }" );
+#endif
     SiBApplication* app = SiBApplication::instance();
 
     app->start();
